OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "قىستۇرما ئۇچۇر% s",
    "Important mail" : "مۇھىم خەت",
    "No message found yet" : "ھازىرچە ھېچقانداق ئۇچۇر تېپىلمىدى",
    "Set up an account" : "ھېسابات قۇر",
    "Unread mail" : "ئوقۇلمىغان خەت",
    "Important" : "مۇھىم",
    "Work" : "ئىش",
    "Personal" : "شەخسىي",
    "To Do" : "قىلىش",
    "Later" : "كېيىنچە",
    "Mail" : "خەت",
    "You are reaching your mailbox quota limit for {account_email}" : "سىز {account_email} for ئۈچۈن خەت ساندۇقىڭىزنىڭ نورمىسىغا يېتىۋاتىسىز",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "سىز ھازىر خەت ساندۇقىڭىزنىڭ {percentage} using نى ئىشلىتىۋاتىسىز. كېرەكسىز ئېلېكترونلۇق خەتلەرنى ئۆچۈرۈپ بىر ئاز بوشلۇق قالدۇرۇڭ.",
    "Mail Application" : "خەت ئىلتىماسى",
    "Mails" : "خەتلەر",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "ئەۋەتكۈچى ئېلېكترونلۇق خەت:%1 $ s ئادرېس دەپتىرىدە ئەمەس ، ئەمما ئەۋەتكۈچىنىڭ ئىسمى:%2 $ s تۆۋەندىكى ئېلېكترونلۇق خەت بىلەن ئادرېس دەپتىرىدە:%3 $ s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "ئەۋەتكۈچى ئېلېكترونلۇق خەت:%1 $ s ئادرېس دەپتىرىدە ئەمەس ، ئەمما ئەۋەتكۈچىنىڭ ئىسمى:%2 $ s تۆۋەندىكى ئېلېكترونلۇق خەتلەر بىلەن ئادرېس دەپتىرىدە:%3 $ s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "ئەۋەتكۈچى ئىختىيارى ئېلېكترونلۇق خەت ئىشلىتىۋاتىدۇ: ئەۋەتكۈچى ئېلېكترونلۇق خەتنىڭ ئورنىغا%1 $ s:%2 $ s",
    "Sent date is in the future" : "ئەۋەتىلگەن ۋاقىت كەلگۈسىدە",
    "Some addresses in this message are not matching the link text" : "بۇ ئۇچۇردىكى بەزى ئادرېسلار ئۇلىنىش تېكىستىگە ماس كەلمەيدۇ",
    "Reply-To email: %1$s  is different from the sender email: %2$s" : "جاۋاب: ئېلېكترونلۇق خەت:%1 $ s ئەۋەتكۈچى ئېلېكترونلۇق خەتكە ئوخشىمايدۇ:%2 $ s",
    "💌 A mail app for Nextcloud" : "Next Nextcloud نىڭ خەت ئەپى",
    "Your session has expired. The page will be reloaded." : "سىزنىڭ ۋاقتىڭىز توشتى. بۇ بەت قايتا يۈكلىنىدۇ.",
    "Drafts are saved in:" : "لايىھە ساقلانغان:",
    "Sent messages are saved in:" : "ئەۋەتىلگەن ئۇچۇرلار:",
    "Deleted messages are moved in:" : "ئۆچۈرۈلگەن ئۇچۇرلار يۆتكىلىدۇ:",
    "Archived messages are moved in:" : "ئارخىپلانغان ئۇچۇرلار يۆتكىلىدۇ:",
    "Snoozed messages are moved in:" : "ئوغرىلانغان ئۇچۇرلار يۆتكىلىدۇ:",
    "Junk messages are saved in:" : "ئەخلەت ئۇچۇرلار:",
    "Connecting" : "ئۇلىنىش",
    "Reconnect Google account" : "Google ھېساباتىنى قايتا ئۇلاڭ",
    "Sign in with Google" : "Google بىلەن تىزىملىتىڭ",
    "Reconnect Microsoft account" : "Microsoft ھېساباتىنى قايتا ئۇلاڭ",
    "Sign in with Microsoft" : "Microsoft بىلەن تىزىملىتىڭ",
    "Save" : "ساقلا",
    "Connect" : "باغلان",
    "Looking up configuration" : "سەپلىمىنى ئىزدەۋاتىدۇ",
    "Checking mail host connectivity" : "خەت ساندۇقىنىڭ ئۇلىنىشىنى تەكشۈرۈش",
    "Configuration discovery failed. Please use the manual settings" : "سەپلىمە بايقاش مەغلۇب بولدى. قول تەڭشەكلىرىنى ئىشلىتىڭ",
    "Password required" : "پارول لازىم",
    "Testing authentication" : "دەلىللەش سىنىقى",
    "Awaiting user consent" : "ئىشلەتكۈچىنىڭ ماقۇللۇقىنى ساقلاش",
    "Account created. Please follow the pop-up instructions to link your Google account" : "ھېسابات قۇرۇلدى. Google ھېساباتىڭىزنى ئۇلاش ئۈچۈن ئېچىلغان كۆرسەتمىلەرگە ئەگىشىڭ",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "ھېسابات قۇرۇلدى. Microsoft ھېساباتىڭىزنى ئۇلاش ئۈچۈن ئېچىلغان كۆرسەتمىلەرگە ئەگىشىڭ",
    "Loading account" : "ھېسابات يۈكلەۋاتىدۇ",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "ھېسابات يېڭىلاندى. Google ھېساباتىڭىزنى قايتا ئۇلاش ئۈچۈن ئېچىلغان كۆرسەتمىلەرگە ئەگىشىڭ",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "ھېسابات يېڭىلاندى. Microsoft ھېساباتىڭىزنى قايتا ئۇلاش ئۈچۈن ئېچىلغان كۆرسەتمىلەرگە ئەگىشىڭ",
    "Account updated" : "ھېسابات يېڭىلاندى",
    "IMAP server is not reachable" : "IMAP مۇلازىمېتىرىغا يەتكىلى بولمايدۇ",
    "SMTP server is not reachable" : "SMTP مۇلازىمېتىرغا يەتكىلى بولمايدۇ",
    "IMAP username or password is wrong" : "IMAP ئىشلەتكۈچى ئىسمى ياكى پارولى خاتا",
    "SMTP username or password is wrong" : "SMTP ئىشلەتكۈچى ئىسمى ياكى پارولى خاتا",
    "IMAP connection failed" : "IMAP ئۇلىنىشى مەغلۇپ بولدى",
    "SMTP connection failed" : "SMTP ئۇلىنىشى مەغلۇپ بولدى",
    "Authorization pop-up closed" : "ھوقۇق كۆزنىكى تاقالدى",
    "Configuration discovery temporarily not available. Please try again later." : "سەپلىمە بايقاشنى ۋاقتىنچە ئىشلەتكىلى بولمايدۇ. كېيىن قايتا سىناڭ.",
    "There was an error while setting up your account" : "ھېساباتىڭىزنى تەڭشىگەندە خاتالىق كۆرۈلدى",
    "Auto" : "ئاپتوماتىك",
    "Name" : "ئاتى",
    "Mail address" : "خەت ئادرېسى",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Name@example.com فورماتىنىڭ ئېلېكترونلۇق خەت ساندۇقىنى كىرگۈزۈڭ",
    "Password" : "ئىم",
    "Manual" : "Manual",
    "IMAP Settings" : "IMAP تەڭشەكلىرى",
    "IMAP Host" : "IMAP Host",
    "IMAP Security" : "IMAP بىخەتەرلىك",
    "None" : "يوق",
    "SSL/TLS" : "SSL / TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP ئېغىزى",
    "IMAP User" : "IMAP ئىشلەتكۈچى",
    "IMAP Password" : "IMAP پارول",
    "SMTP Settings" : "SMTP تەڭشىكى",
    "SMTP Host" : "SMTP رىياسەتچىسى",
    "SMTP Security" : "SMTP بىخەتەرلىك",
    "SMTP Port" : "SMTP ئېغىزى",
    "SMTP User" : "SMTP ئىشلەتكۈچى",
    "SMTP Password" : "SMTP پارول",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "گۇگۇل ھېساباتىنىڭ بۇ دېتال بىلەن ئىشلىشى ئۈچۈن گۇگۇل ئۈچۈن ئىككى ئامىللىق دەلىللەشنى قوزغىتىپ ، بىر پارول ھاسىل قىلىشىڭىز كېرەك.",
    "Account settings" : "ھېسابات تەڭشىكى",
    "Aliases" : "Aliases",
    "Alias to S/MIME certificate mapping" : "S / MIME گۇۋاھنامىسىنىڭ خەرىتىسى",
    "Signature" : "ئىمزا",
    "A signature is added to the text of new messages and replies." : "يېڭى ئۇچۇر ۋە جاۋابلارنىڭ تېكىستىگە ئىمزا قوشۇلدى.",
    "Writing mode" : "يېزىش ھالىتى",
    "Preferred writing mode for new messages and replies." : "يېڭى ئۇچۇرلار ۋە جاۋابلارنىڭ ياقتۇرىدىغان يېزىش ھالىتى.",
    "Default folders" : "كۆڭۈلدىكى ھۆججەت قىسقۇچ",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "لايىھە ، ئەۋەتىلگەن ئۇچۇر ، ئۆچۈرۈلگەن ئۇچۇرلار ، ئارخىپلانغان ئۇچۇرلار ۋە ئەخلەت ئۇچۇرلار ئۈچۈن ئىشلىتىلىدىغان ھۆججەت قىسقۇچلار.",
    "Automatic trash deletion" : "ئەخلەت ساندۇقىنى ئاپتوماتىك ئۆچۈرۈش",
    "Days after which messages in Trash will automatically be deleted:" : "ئەخلەت ساندۇقىدىكى ئۇچۇرلار ئاپتوماتىك ئۆچۈرۈلىدۇ:",
    "Autoresponder" : "Autoresponder",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "كەلگەن ئۇچۇرلارغا ئاپتوماتىك جاۋاب. ئەگەر بىرسى سىزگە بىر قانچە ئۇچۇر ئەۋەتسە ، بۇ ئاپتوماتىك جاۋاب ھەر 4 كۈندە بىر قېتىم ئەۋەتىلىدۇ.",
    "Filters" : "سۈزگۈچ",
    "Sieve script editor" : "قوليازما تەھرىرلىگۈچ",
    "Mail server" : "خەت مۇلازىمېتىرى",
    "Sieve server" : "مۇلازىمېتىر",
    "Update alias" : "نامىنى يېڭىلاش",
    "Rename alias" : "نامىنى ئۆزگەرتىڭ",
    "Show update alias form" : "يېڭىلاش نامىنى كۆرسىتىدۇ",
    "Delete alias" : "ئۆچۈرۈڭ",
    "Go back" : "قايتىڭ",
    "Change name" : "ئىسىم ئۆزگەرتىش",
    "Email address" : "ئېلخەت ئادرېسى",
    "Add alias" : "ئالياس قوشۇڭ",
    "Create alias" : "Alias قۇر",
    "Cancel" : "ۋاز كەچ",
    "Search in the body of messages in priority Inbox" : "مۇھىم خەت ساندۇقىدىكى ئۇچۇرلارنىڭ گەۋدىسىدىن ئىزدەڭ",
    "Activate" : "ئاكتىپلاش",
    "Put my text to the bottom of a reply instead of on top of it." : "تېكىستنى ئۇنىڭ ئورنىغا جاۋابنىڭ ئاستىغا قويۇڭ.",
    "Mark as important" : "مۇھىم دەپ بەلگە قويۇڭ",
    "Remind about messages that require a reply but received none" : "جاۋاب تەلەپ قىلىدىغان ، ئەمما تاپشۇرۇۋالمىغان ئۇچۇرلارنى ئەسكەرتىڭ",
    "Use internal addresses" : "ئىچكى ئادرېسنى ئىشلىتىڭ",
    "Could not update preference" : "مايىللىقنى يېڭىلىيالمىدى",
    "Mail settings" : "خەت تەڭشەكلىرى",
    "Accounts" : "ھېسابات",
    "Add mail account" : "خەت ھېساباتى قوشۇڭ",
    "Settings for:" : "تەڭشەكلەر:",
    "General" : "ئادەتتىكى",
    "Layout" : "Layout",
    "List" : "تىزىملىك",
    "Vertical split" : "ۋېرتىكال بۆلۈنۈش",
    "Horizontal split" : "توغرىسىغا بۆلۈنگەن",
    "Sorting" : "تەرتىپلەش",
    "Newest" : "ئەڭ يېڭى",
    "Oldest" : "ئەڭ كونا",
    "Search in body" : "بەدەندە ئىزدەش",
    "Reply text position" : "تېكىست ئورنىغا جاۋاب بېرىڭ",
    "Gravatar settings" : "Gravatar settings",
    "Use Gravatar and favicon avatars" : "Gravatar ۋە favicon باش سۈرىتىنى ئىشلىتىڭ",
    "Mailto" : "Mailto",
    "Register as application for mail links" : "خەت ئۇلانمىسىغا ئىلتىماس قىلىڭ",
    "Register" : "تىزىملىتىڭ",
    "Privacy and security" : "مەخپىيەتلىك ۋە بىخەتەرلىك",
    "Data collection consent" : "ئۇچۇر توپلاش ئىجازەتنامىسى",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "بۇ دېتالنىڭ ئۆز-ئارا تەسىرلىشىڭىزگە مۇناسىۋەتلىك ئۇچۇرلارنى توپلىشىغا يول قويۇڭ. بۇ سانلىق مەلۇماتلارغا ئاساسەن ، ئەپ سىزنىڭ مايىللىقىڭىزغا ماسلىشىدۇ. بۇ سانلىق مەلۇماتلار پەقەت يەرلىكتە ساقلىنىدۇ.",
    "Trusted senders" : "ئىشەنچلىك ئەۋەتكۈچىلەر",
    "Internal addresses" : "ئىچكى ئادرېس",
    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "بۇ ئىقتىدارنى قوزغىتىش ئارقىلىق تاشقى ئېلېكترونلۇق خەت ئادرېسىنى گەۋدىلەندۈرۈڭ ، ئىچكى ئادرېسىڭىز ۋە تور دائىرىڭىزنى باشقۇرۇپ ، تونۇلغان ئالاقىنىڭ بەلگىسىز بولۇشىغا كاپالەتلىك قىلىڭ.",
    "S/MIME" : "S / MIME",
    "Manage S/MIME certificates" : "S / MIME گۇۋاھنامىسىنى باشقۇرۇش",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain!" : "خەت ساندۇقى نۆۋەتتىكى دائىرە ئۈچۈن قوزغىتىلدى!",
    "Looking for a way to encrypt your emails?" : "ئېلېكترونلۇق خەتلىرىڭىزنى مەخپىيلەشتۈرۈشنىڭ يولىنى ئىزدەۋاتامسىز؟",
    "Enable Mailvelope for the current domain" : "نۆۋەتتىكى دائىرە ئۈچۈن Mailvelope نى قوزغىتىڭ",
    "Assistance features" : "ياردەم ئىقتىدارلىرى",
    "About" : "ھەققىدە",
    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
    "Compose new message" : "يېڭى ئۇچۇر يېزىڭ",
    "Newer message" : "يېڭى ئۇچۇر",
    "Older message" : "كونا ئۇچۇر",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "ئوقۇشسىز",
    "Archive" : "ئارخىپ",
    "Delete" : "ئۆچۈر",
    "Search" : "Search",
    "Send" : "يوللا",
    "Refresh" : "يېڭىلا",
    "No certificate" : "گۇۋاھنامە يوق",
    "Certificate updated" : "گۇۋاھنامە يېڭىلاندى",
    "Could not update certificate" : "گۇۋاھنامىنى يېڭىلىيالمىدى",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - {expiryDate} غىچە كۈچكە ئىگە",
    "Select an alias" : "باشقا ئىسىمنى تاللاڭ",
    "Select certificates" : "گۇۋاھنامە تاللاڭ",
    "Update Certificate" : "گۇۋاھنامىنى يېڭىلاش",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "تاللانغان گۇۋاھنامە مۇلازىمېتىرغا ئىشەنمەيدۇ. تاپشۇرۇۋالغۇچىلار ئىمزاڭىزنى دەلىللىيەلمەسلىكى مۇمكىن.",
    "Encrypt with S/MIME and send later" : "S / MIME بىلەن مەخپىيلەشتۈرۈڭ ۋە كېيىن ئەۋەتىڭ",
    "Encrypt with S/MIME and send" : "S / MIME بىلەن مەخپىيلەشتۈرۈڭ ۋە ئەۋەتىڭ",
    "Encrypt with Mailvelope and send later" : "Mailvelope بىلەن مەخپىيلەشتۈرۈڭ ۋە كېيىن ئەۋەتىڭ",
    "Encrypt with Mailvelope and send" : "Mailvelope بىلەن مەخپىيلەشتۈرۈڭ ۋە ئەۋەتىڭ",
    "Send later" : "كېيىن ئەۋەتىڭ",
    "Message {id} could not be found" : "ئۇچۇر {id} تېپىلمىدى",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "S / MIME بىلەن ئىمزا ياكى مەخپىيلەشتۈرۈش تاللاندى ، ئەمما بىزنىڭ تاللانغان تەخەللۇس ئىسپاتىمىز يوق. بۇ ئۇچۇر ئىمزالانمايدۇ ياكى مەخپىيلەشتۈرۈلمەيدۇ.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "مەۋجۇت فورمات (مەسىلەن توم ، يانتۇ ، ئاستى سىزىق ياكى سىزىقلىق رەسىملەر) ئۆچۈرۈلىدۇ.",
    "Turn off formatting" : "فورماتنى تاقاڭ",
    "Turn off and remove formatting" : "فورماتنى ئېتىۋېتىڭ",
    "Keep formatting" : "فورماتنى ساقلاڭ",
    "From" : "From",
    "Select account" : "ھېساباتنى تاللاڭ",
    "To" : "To",
    "Cc/Bcc" : "Cc / Bcc",
    "Select recipient" : "تاپشۇرۇۋالغۇچىنى تاللاڭ",
    "Contact or email address …" : "ئالاقىلىشىش ياكى ئېلېكترونلۇق خەت ئادرېسى…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "تېما",
    "Subject …" : "تېما…",
    "This message came from a noreply address so your reply will probably not be read." : "بۇ ئۇچۇر ناتوغرا ئادرېستىن كەلگەن ، شۇڭا جاۋابىڭىز ئوقۇلماسلىقى مۇمكىن.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "تۆۋەندىكى تاپشۇرۇۋالغۇچىلارنىڭ S / MIME گۇۋاھنامىسى يوق: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "تۆۋەندىكى تاپشۇرۇۋالغۇچىلارنىڭ PGP ئاچقۇچى يوق: {recipients}.",
    "Write message …" : "ئۇچۇر يېزىڭ…",
    "Saving draft …" : "لايىھە تېجەش…",
    "Error saving draft" : "لايىھە تېجەشتە خاتالىق",
    "Draft saved" : "لايىھە ساقلاندى",
    "Save draft" : "لايىھەنى ساقلاڭ",
    "Discard & close draft" : "لايىھەنى ئەمەلدىن قالدۇرۇش ۋە تاقاش",
    "Enable formatting" : "فورماتلاشنى قوزغىتىڭ",
    "Disable formatting" : "فورماتنى چەكلەڭ",
    "Upload attachment" : "قوشۇمچە ھۆججەتنى يۈكلەڭ",
    "Add attachment from Files" : "ھۆججەتلەردىن قوشۇمچە ھۆججەت قوشۇڭ",
    "Add share link from Files" : "ھۆججەتلەردىن ھەمبەھىر ئۇلانمىسىنى قوشۇڭ",
    "Smart picker" : "ئەقىللىق تاللىغۇچ",
    "Request a read receipt" : "ئوقۇش تالونىنى تەلەپ قىلىڭ",
    "Sign message with S/MIME" : "S / MIME بىلەن ئۇچۇر ئىمزالاڭ",
    "Encrypt message with S/MIME" : "S / MIME ئارقىلىق ئۇچۇرنى مەخپىيلەشتۈرۈڭ",
    "Encrypt message with Mailvelope" : "Mailvelope بىلەن ئۇچۇرنى مەخپىيلەشتۈرۈڭ",
    "Send now" : "ھازىر ئەۋەتىڭ",
    "Tomorrow morning" : "ئەتە ئەتىگەن",
    "Tomorrow afternoon" : "ئەتە چۈشتىن كېيىن",
    "Monday morning" : "دۈشەنبە ئەتىگەن",
    "Custom date and time" : "ئىختىيارى چېسلا ۋە ۋاقىت",
    "Enter a date" : "چېسلانى كىرگۈزۈڭ",
    "Choose" : "تاللاڭ",
    "Choose a file to add as attachment" : "قوشۇمچە قىلىپ قوشماقچى بولغان ھۆججەتنى تاللاڭ",
    "Choose a file to share as a link" : "ئۇلىنىش سۈپىتىدە ھەمبەھىرلىنىدىغان ھۆججەتنى تاللاڭ",
    "Untitled message" : "نامسىز ئۇچۇر",
    "Expand composer" : "كومپوزىتورنى كېڭەيتىڭ",
    "Close composer" : "كومپوزىتورنى تاقاش",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Tag: {name} deleted" : "خەتكۈچ: {name} ئۆچۈرۈلدى",
    "An error occurred, unable to delete the tag." : "خەتكۈچنى ئۆچۈرەلمەي خاتالىق كۆرۈلدى.",
    "The tag will be deleted from all messages." : "خەتكۈچ بارلىق ئۇچۇرلاردىن ئۆچۈرۈلىدۇ.",
    "Plain text" : "تۈز تېكىست",
    "Rich text" : "مول تېكىست",
    "No messages" : "ھېچقانداق ئۇچۇر يوق",
    "Blind copy recipients only" : "پەقەت ئەمالار كۆپەيتكۈچى",
    "No subject" : "تېما يوق",
    "Later today – {timeLocale}" : "كېيىن بۈگۈن - {timeLocale}",
    "Set reminder for later today" : "بۈگۈنگە ئەسكەرتىش بەلگىلەڭ",
    "Tomorrow – {timeLocale}" : "ئەتە - {timeLocale}",
    "Set reminder for tomorrow" : "ئەتە ئۈچۈن ئەسكەرتىش بەلگىلەڭ",
    "This weekend – {timeLocale}" : "بۇ ھەپتە ئاخىرى - {timeLocale}",
    "Set reminder for this weekend" : "بۇ ھەپتە ئاخىرىدا ئەسكەرتىش بەلگىلەڭ",
    "Next week – {timeLocale}" : "كېلەر ھەپتە - {timeLocale}",
    "Set reminder for next week" : "كېلەر ھەپتە ئەسكەرتىش بەلگىلەڭ",
    "Could not delete message" : "ئۇچۇرنى ئۆچۈرەلمىدى",
    "Could not archive message" : "ئۇچۇرنى ئارخىپلاشتۇرالمىدى",
    "Thread was snoozed" : "تېما قىسقارتىلدى",
    "Could not snooze thread" : "تېمىنى بوشاشتۇرالمىدى",
    "Thread was unsnoozed" : "تېما ئېچىلمىدى",
    "Could not unsnooze thread" : "تېمىنى ئاچقىلى بولمىدى",
    "Encrypted message" : "شىفىرلانغان ئۇچۇر",
    "This message is unread" : "بۇ ئۇچۇر ئوقۇلمىدى",
    "Unfavorite" : "ياقتۇرمايدىغان",
    "Favorite" : "يىغقۇچ",
    "Unread" : "ئوقۇمىغان",
    "Read" : "ئوقۇ",
    "Unimportant" : "مۇھىم ئەمەس",
    "Mark not spam" : "ئەخلەت خەت ئەمەس",
    "Mark as spam" : "ئەخلەت خەت دەپ بەلگە قويۇڭ",
    "Edit tags" : "خەتكۈچلەرنى تەھرىرلەش",
    "Snooze" : "Snooze",
    "Unsnooze" : "Unsnooze",
    "Move thread" : "تېمىنى يۆتكەڭ",
    "Archive thread" : "ئارخىپ تېمىسى",
    "Archive message" : "ئارخىپ ئۇچۇرى",
    "Delete thread" : "تېمىنى ئۆچۈرۈڭ",
    "Delete message" : "ئۇچۇرنى ئۆچۈرۈڭ",
    "More actions" : "تېخىمۇ كۆپ ھەرىكەت",
    "Back" : "قايتىش",
    "Set custom snooze" : "ئىختىيارى ئۇخلاشنى تەڭشەڭ",
    "Edit as new message" : "يېڭى ئۇچۇر سۈپىتىدە تەھرىرلەڭ",
    "Create event" : "ھادىسە قۇرۇش",
    "Create task" : "ۋەزىپە قۇرۇش",
    "Download message" : "ئۇچۇرنى چۈشۈرۈش",
    "Load more" : "تېخىمۇ كۆپ يۈكلەڭ",
    "Report this bug" : "بۇ خاتالىقنى دوكلات قىلىڭ",
    "Event created" : "پائالىيەت قۇرۇلدى",
    "Could not create event" : "ھادىسە قۇرالمىدى",
    "All day" : "پۈتۈن كۈن",
    "Select calendar" : "كالېندارنى تاللاڭ",
    "Description" : "چۈشەندۈرۈش",
    "Create" : "قۇر",
    "This event was updated" : "بۇ پائالىيەت يېڭىلاندى",
    "{attendeeName} accepted your invitation" : "{attendeeName} your تەكلىپىڭىزنى قوبۇل قىلدى",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} your تەكلىپىڭىزنى ۋاقتىنچە قوبۇل قىلدى",
    "{attendeeName} declined your invitation" : "{attendeeName} your تەكلىپىڭىزنى رەت قىلدى",
    "{attendeeName} reacted to your invitation" : "{attendeeName} your سىزنىڭ تەكلىۋىڭىزگە ئىنكاس قايتۇردى",
    "Failed to save your participation status" : "قاتنىشىش ھالىتىڭىزنى ساقلاپ قالالمىدى",
    "You accepted this invitation" : "سىز بۇ تەكلىپنى قوبۇل قىلدىڭىز",
    "You tentatively accepted this invitation" : "سىز بۇ تەكلىپنى ۋاقتىنچە قوبۇل قىلدىڭىز",
    "You declined this invitation" : "سىز بۇ تەكلىپنى رەت قىلدىڭىز",
    "You already reacted to this invitation" : "سىز بۇ تەكلىپكە ئىنكاس قايتۇردىڭىز",
    "You have been invited to an event" : "سىزنى بىر پائالىيەتكە تەكلىپ قىلدىڭىز",
    "This event was cancelled" : "بۇ پائالىيەت ئەمەلدىن قالدۇرۇلدى",
    "Save to" : "ساقلىۋېلىڭ",
    "Select" : "Select",
    "Comment" : "باھا",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "Tentatively accept" : "Tentatively accept",
    "More options" : "تېخىمۇ كۆپ تاللاشلار",
    "Could not remove internal address {sender}" : "ئىچكى ئادرېس {sender} ئۆچۈرەلمىدى",
    "Could not add internal address {address}" : "ئىچكى ئادرېس {address} قوشالمىدى",
    "individual" : "يەككە",
    "domain" : "دائىرە",
    "Remove" : "چىقىرىۋەت",
    "email" : "ئېلېكترونلۇق خەت",
    "Add internal address" : "ئىچكى ئادرېس قوشۇڭ",
    "Add internal email or domain" : "ئىچكى ئېلېكترونلۇق خەت ياكى دائىرە قوشۇڭ",
    "Itinerary for {type} is not supported yet" : "{type} نىڭ لىنىيىسى تېخىچە قوللىمايدۇ",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "بۇ ئۇچۇرنى ئارخىپ قىسقۇچقا يۆتكەش ۋە / ياكى بۇ ھۆججەتنى نۆۋەتتىكى ھۆججەت قىسقۇچتىن ئۆچۈرۈشكە بولمايدۇ",
    "Loading messages …" : "ئۇچۇرلارنى يۈكلەۋاتىدۇ…",
    "Choose target folder" : "نىشان ھۆججەت قىسقۇچىنى تاللاڭ",
    "No more submailboxes in here" : "بۇ يەردە باشقا خەت ساندۇقى يوق",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "سىز قايسى ئۇچۇرلار بىلەن ئالاقە قىلغان ياكى مۇھىم دەپ بەلگە قويۇلغان ئۇچۇرلار ئاپتوماتىك ھالدا مۇھىم دەپ بەلگە قىلىنىدۇ. باشتا سىز سىستېمىنى ئوقۇتۇشنىڭ مۇھىملىقىنى قولدا ئۆزگەرتىشىڭىز مۇمكىن ، ئەمما ۋاقىتنىڭ ئۆتۈشىگە ئەگىشىپ ياخشىلىنىدۇ.",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "سىز ئەۋەتكەن جاۋابنى تەلەپ قىلىدىغان ، ئەمما بىر نەچچە كۈندىن كېيىن تاپشۇرۇۋالمىغان ئۇچۇرلار بۇ يەردە كۆرسىتىلىدۇ.",
    "Follow up" : "ئەگىشىڭ",
    "Follow up info" : "ئۇچۇرغا ئەگىشىڭ",
    "Important info" : "مۇھىم ئۇچۇرلار",
    "Other" : "باشقا",
    "Could not send mdn" : "Mdn ئەۋەتەلمىدى",
    "The sender of this message has asked to be notified when you read this message." : "بۇ ئۇچۇرنى ئەۋەتكۈچى بۇ ئۇچۇرنى ئوقۇغاندا ئۇقتۇرۇش قىلىشنى تەلەپ قىلغان.",
    "Notify the sender" : "ئەۋەتكۈچىگە خەۋەر قىلىڭ",
    "You sent a read confirmation to the sender of this message." : "سىز بۇ ئۇچۇرنى ئەۋەتكۈچىگە ئوقۇش جەزملەشتۈردى.",
    "Message was snoozed" : "ئۇچۇر ئوغرىلاندى",
    "Could not snooze message" : "ئۇچۇرنى بوشاشتۇرالمىدى",
    "Message was unsnoozed" : "ئۇچۇر بىكار قىلىنمىدى",
    "Could not unsnooze message" : "ئۇچۇرنى بىكار قىلالمىدى",
    "Forward" : "ئالدىغا",
    "Move message" : "ئۇچۇر يۆتكەش",
    "Translate" : "تەرجىمە قىلىڭ",
    "Forward message as attachment" : "قوشۇمچە ئۇچۇر سۈپىتىدە قوشۇمچە ئۇچۇر",
    "View source" : "مەنبەنى كۆرۈش",
    "Print message" : "ئۇچۇر بېسىش",
    "Download thread data for debugging" : "خاتالىق ئۇچۇرىنى چۈشۈرۈڭ",
    "Message body" : "ئۇچۇر گەۋدىسى",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "ئاگاھلاندۇرۇش: بۇ ئۇچۇرنىڭ S / MIME ئىمزاسى دەلىللەنمىگەن. ئەۋەتكۈچى بەلكىم باشقىلارغا ئوخشىتىپ قويغان بولۇشى مۇمكىن!",
    "Unnamed" : "نامسىز",
    "Embedded message" : "قىستۇرما ئۇچۇر",
    "Attachment saved to Files" : "قوشۇمچە ھۆججەت ھۆججەتلەرگە ساقلاندى",
    "Attachment could not be saved" : "قوشۇمچە ھۆججەتنى ساقلىغىلى بولمايدۇ",
    "calendar imported" : "كالېندار ئىمپورت قىلىندى",
    "Choose a folder to store the attachment in" : "قوشۇمچە ھۆججەتنى ساقلاش ئۈچۈن ھۆججەت قىسقۇچنى تاللاڭ",
    "Import into calendar" : "كالېندارغا ئەكىرىڭ",
    "Download attachment" : "قوشۇمچە ھۆججەتنى چۈشۈرۈڭ",
    "Save to Files" : "ھۆججەتلەرگە ساقلاڭ",
    "Attachments saved to Files" : "ھۆججەتلەرگە ساقلانغان قوشۇمچە ھۆججەتلەر",
    "Error while saving attachments" : "قوشۇمچە ھۆججەتلەرنى ساقلاش جەريانىدا خاتالىق",
    "View fewer attachments" : "قوشۇمچە ھۆججەتلەرنى ئاز كۆرۈڭ",
    "Choose a folder to store the attachments in" : "قوشۇمچە ھۆججەتلەرنى ساقلاش ئۈچۈن ھۆججەت قىسقۇچنى تاللاڭ",
    "Save all to Files" : "ھەممىنى ھۆججەتلەرگە ساقلاڭ",
    "Download Zip" : "Zip نى چۈشۈرۈڭ",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "بۇ ئۇچۇر PGP بىلەن مەخپىيلەشتۈرۈلگەن. ئۇنى مەخپىيلەشتۈرۈش ئۈچۈن Mailvelope نى قاچىلاڭ.",
    "The images have been blocked to protect your privacy." : "مەخپىيەتلىكىڭىزنى قوغداش ئۈچۈن رەسىملەر توسۇلۇپ قالدى.",
    "Show images" : "رەسىملەرنى كۆرسىتىش",
    "Show images temporarily" : "رەسىملەرنى ۋاقىتلىق كۆرسەت",
    "Always show images from {sender}" : "ھەمىشە {sender} from دىن رەسىملەرنى كۆرسىتىڭ",
    "Always show images from {domain}" : "ھەمىشە {domain} from دىكى رەسىملەرنى كۆرسىتىڭ",
    "Message frame" : "ئۇچۇر رامكىسى",
    "Quoted text" : "نەقىل ئېلىنغان تېكىست",
    "Move" : "Move",
    "Moving" : "يۆتكىلىش",
    "Moving thread" : "يۆتكىلىشچان تېما",
    "Moving message" : "يۆتكىلىشچان ئۇچۇر",
    "Remove account" : "ھېساباتنى ئۆچۈرۈڭ",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} خەت} ۋە غەملەك ئېلېكترونلۇق خەت سانلىق مەلۇماتلىرىنىڭ ھېساباتى Nextcloud دىن ئۆچۈرۈلىدۇ ، ئەمما ئېلېكترونلۇق خەت تەمىنلىگۈچىڭىزدىن ئۆچۈرۈلمەيدۇ.",
    "Remove {email}" : "Remove {email}",
    "Provisioned account is disabled" : "تەمىنلەنگەن ھېسابات چەكلەنگەن",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "بۇ ھېساباتنى قوزغىتىش ئۈچۈن پارول ئىشلىتىپ كىرىڭ. نۆۋەتتىكى يىغىن مەخپىي نومۇرسىز دەلىللەشنى ئىشلىتىۋاتىدۇ. SSO ياكى WebAuthn.",
    "Add folder" : "قىسقۇچ قوشۇڭ",
    "Folder name" : "ھۆججەت قىسقۇچنىڭ ئىسمى",
    "Saving" : "تېجەش",
    "Move up" : "يۆتكەڭ",
    "Move down" : "تۆۋەنگە يۆتكەڭ",
    "Collapse mailboxes" : "خەت ساندۇقىنى يىمىرىڭ",
    "Loading …" : "Loading…",
    "All messages in mailbox will be deleted." : "خەت ساندۇقىدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
    "Clear mailbox {name}" : "خەت ساندۇقىنى تازىلاش {name}",
    "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
    "An error occurred, unable to rename the mailbox." : "خاتالىق يۈز بەردى ، خەت ساندۇقىنىڭ نامىنى ئۆزگەرتەلمىدى.",
    "Please wait 10 minutes before repairing again" : "قايتا رېمونت قىلىشتىن 10 مىنۇت ساقلاڭ",
    "Mark all as read" : "ھەممىنى ئوقۇغاندەك بەلگە قويۇڭ",
    "Rename" : "ئات ئۆزگەرت",
    "Move folder" : "ھۆججەت قىسقۇچنى يۆتكەڭ",
    "Clear cache" : "غەملەكنى تازىلاش",
    "Clear locally cached data, in case there are issues with synchronization." : "ماس قەدەمدە مەسىلە كۆرۈلسە ، يەرلىك ساقلانغان سانلىق مەلۇماتلارنى تازىلاڭ.",
    "Subscribed" : "مۇشتەرى بولدى",
    "Sync in background" : "تەگلىكتە ماسقەدەملەش",
    "Outbox" : "Outbox",
    "New message" : "يېڭى ئۇچۇر",
    "Edit message" : "ئۇچۇرنى تەھرىرلەش",
    "Draft" : "لايىھە",
    "Reply" : "جاۋاب قايتۇر",
    "Message saved" : "ئۇچۇر ساقلاندى",
    "Failed to save message" : "ئۇچۇرنى ساقلاش مەغلۇب بولدى",
    "Failed to save draft" : "لايىھەنى ساقلىيالمىدى",
    "attachment" : "attachment",
    "attached" : "باغلانغان",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "سىز To ۋە / ياكى Cc دىكى نۇرغۇن تاپشۇرۇۋالغۇچىلارغا ئەۋەتمەكچى بولۇۋاتىسىز. تاپشۇرۇۋالغۇچىنىڭ ئادرېسىنى يوشۇرۇش ئۈچۈن Bcc نى ئىشلىتىشنى ئويلاڭ.",
    "You mentioned an attachment. Did you forget to add it?" : "قوشۇمچە ھۆججەتنى تىلغا ئالدىڭىز. ئۇنى قوشۇشنى ئۇنتۇپ قالدىڭىزمۇ؟",
    "Message discarded" : "ئۇچۇر تاشلىۋېتىلدى",
    "Could not discard message" : "ئۇچۇرنى تاشلىۋېتەلمىدى",
    "Maximize composer" : "كومپوزىتورنى چوڭايتىڭ",
    "Minimize composer" : "كومپوزىتورنى كىچىكلىتىڭ",
    "Error sending your message" : "ئۇچۇرىڭىزنى ئەۋەتىشتە خاتالىق",
    "Retry" : "قايتا سىناڭ",
    "Warning sending your message" : "ئۇچۇرىڭىزنى ئەۋەتىش ھەققىدە ئاگاھلاندۇرۇش",
    "Send anyway" : "قانداقلا بولمىسۇن ئەۋەتىڭ",
    "Autoresponder off" : "Autoresponder off",
    "Autoresponder on" : "Autoresponder on",
    "Autoresponder follows system settings" : "Autoresponder سىستېما تەڭشىكىگە ئەگىشىدۇ",
    "The autoresponder follows your personal absence period settings." : "ئاپتوماتىك جاۋاب بەرگۈچى سىزنىڭ شەخسىي يوقلۇقىڭىزنىڭ تەڭشىكىگە ئەگىشىدۇ.",
    "Edit absence settings" : "يوقلۇق تەڭشەكلىرىنى تەھرىرلەڭ",
    "First day" : "بىرىنچى كۈنى",
    "Last day (optional)" : "ئالدىنقى كۈنى (ئىختىيارىي)",
    "${subject} will be replaced with the subject of the message you are responding to" : "$ {subject} سىز ئىنكاس قىلىۋاتقان ئۇچۇرنىڭ تېمىسى بىلەن ئالماشتۇرۇلىدۇ",
    "Message" : "ئۇچۇر",
    "Oh Snap!" : "ئەي Snap!",
    "Save autoresponder" : "ئاپتوماتىك جاۋاب قايتۇرۇڭ",
    "Could not open outbox" : "خەت ساندۇقىنى ئاچالمىدى",
    "Pending or not sent messages will show up here" : "ساقلىنىۋاتقان ياكى ئەۋەتىلمىگەن ئۇچۇرلار بۇ يەردە كۆرۈنىدۇ",
    "Mail server error" : "خەت مۇلازىمېتىر خاتالىقى",
    "Message could not be sent" : "ئۇچۇر ئەۋەتىلمىدى",
    "Message deleted" : "ئۇچۇر ئۆچۈرۈلدى",
    "Phishing email" : "ئالدامچىلىق ئېلېكترونلۇق خەت",
    "This email might be a phishing attempt" : "بۇ ئېلېكترونلۇق خەت ئالدامچىلىق بولۇشى مۇمكىن",
    "Hide suspicious links" : "گۇمانلىق ئۇلىنىشلارنى يوشۇرۇڭ",
    "Show suspicious links" : "گۇمانلىق ئۇلىنىشلارنى كۆرسەت",
    "link text" : "ئۇلىنىش تېكىستى",
    "Copied email address to clipboard" : "ئېلېكترونلۇق خەت ئادرېسىنى چاپلاش تاختىسىغا كۆچۈردى",
    "Could not copy email address to clipboard" : "ئېلېكترونلۇق خەت ئادرېسىنى چاپلاش تاختىسىغا كۆچۈرەلمىدى",
    "Contacts with this address" : "بۇ ئادرېس بىلەن ئالاقىلىشىڭ",
    "Add to Contact" : "ئالاقىلىشىشكە قوشۇڭ",
    "New Contact" : "يېڭى ئالاقىلىشىش",
    "Copy to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈڭ",
    "Contact name …" : "ئالاقىلىشىش ئىسمى…",
    "Add" : "قوش",
    "Show less" : "ئازراق كۆرسەت",
    "Show more" : "تېخىمۇ كۆپ كۆرسەت",
    "Clear" : "Clear",
    "Close" : "ياپ",
    "Search parameters" : "ئىزدەش پارامېتىرلىرى",
    "Search subject" : "ئىزدەش تېمىسى",
    "Body" : "بەدەن",
    "Search body" : "ئىزدەش گەۋدىسى",
    "Date" : "Date",
    "Pick a start date" : "باشلىنىش ۋاقتىنى تاللاڭ",
    "Pick an end date" : "ئاخىرلىشىش ۋاقتىنى تاللاڭ",
    "Select senders" : "ئەۋەتكۈچىلەرنى تاللاڭ",
    "Select recipients" : "تاپشۇرۇۋالغۇچىلارنى تاللاڭ",
    "Select CC recipients" : "CC تاپشۇرۇۋالغۇچىلارنى تاللاڭ",
    "Select BCC recipients" : "BCC تاپشۇرۇۋالغۇچىلارنى تاللاڭ",
    "Tags" : "بەلگەلەر",
    "Select tags" : "خەتكۈچلەرنى تاللاڭ",
    "Marked as" : "دەپ بەلگە قويۇلغان",
    "Has attachments" : "قوشۇمچە ھۆججەتلىرى بار",
    "Mentions me" : "Mentions me",
    "Has attachment" : "قوشۇمچە ھۆججەت بار",
    "Last 7 days" : "ئاخىرقى 7 كۈن",
    "From me" : "مەندىن",
    "Enable mail body search" : "خەت ساندۇقىنى ئىزدەشنى قوزغىتىڭ",
    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "ئەلگەك ساندۇقىڭىزغا سۈزگۈچ يېزىشتىكى كۈچلۈك تىل. ئەگەر ئېلېكترونلۇق خەت مۇلازىمىتىڭىز ئۇنى قوللىسا ، خەتتىكى ئەلگەك ئورگىناللىرىنى باشقۇرالايسىز. ئەلگەكتىن يەنە ئاپتوماتىك جاۋاب قايتۇرۇش ۋە سۈزگۈچ ئىشلىتىش تەلەپ قىلىنىدۇ.",
    "Enable sieve filter" : "ئەلگەك سۈزگۈچنى قوزغىتىڭ",
    "Sieve host" : "ساھىبجامال",
    "Sieve security" : "بىخەتەرلىكنى قولغا كەلتۈرۈش",
    "Sieve Port" : "Sieve Port",
    "Sieve credentials" : "سالاھىيەت گۇۋاھنامىسى",
    "IMAP credentials" : "IMAP كىنىشكىسى",
    "Custom" : "Custom",
    "Sieve User" : "Sieve User",
    "Sieve Password" : "مەخپىي نومۇر",
    "Oh snap!" : "ئاھ!",
    "Save sieve settings" : "ئەلگەك تەڭشەكلىرىنى ساقلاڭ",
    "The syntax seems to be incorrect:" : "گرامماتىكىسى خاتادەك قىلىدۇ:",
    "Save sieve script" : "ئەلگەك قوليازمىسىنى ساقلاڭ",
    "Signature …" : "ئىمزا…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "ئىمزاسىڭىز 2 MB دىن چوڭ. بۇ بەلكىم تەھرىرىڭىزنىڭ ئىقتىدارىغا تەسىر كۆرسىتىشى مۇمكىن.",
    "Save signature" : "ئىمزا ساقلاڭ",
    "Place signature above quoted text" : "ئىمزانى نەقىل ئېلىنغان تېكىستنىڭ ئۈستىگە قويۇڭ",
    "Message source" : "ئۇچۇر مەنبەسى",
    "An error occurred, unable to rename the tag." : "خەتكۈچنىڭ نامىنى ئۆزگەرتىشكە ئامالسىز قالغان.",
    "Edit name or color" : "ئىسىم ياكى رەڭنى تەھرىرلەڭ",
    "Saving new tag name …" : "يېڭى خەتكۈچ نامىنى تېجەش…",
    "Delete tag" : "خەتكۈچنى ئۆچۈرۈڭ",
    "Set tag" : "بەلگە بەلگىلەڭ",
    "Unset tag" : "خەتكۈچنى تەڭشەش",
    "Tag name is a hidden system tag" : "بەلگە ئىسمى يوشۇرۇن سىستېما بەلگىسى",
    "Tag already exists" : "خەتكۈچ مەۋجۇت",
    "Tag name cannot be empty" : "بەلگە ئىسمى قۇرۇق بولمايدۇ",
    "An error occurred, unable to create the tag." : "خەتكۈچ قۇرالماسلىقتا خاتالىق كۆرۈلدى.",
    "Add default tags" : "سۈكۈتتىكى بەلگىلەرنى قوشۇڭ",
    "Add tag" : "خەتكۈچ قوشۇڭ",
    "Saving tag …" : "خەتكۈچنى ساقلاش…",
    "Task created" : "ۋەزىپە قۇرۇلدى",
    "Could not create task" : "ۋەزىپە قۇرالمىدى",
    "No calendars with task list support" : "ۋەزىپە تىزىملىكى قوللايدىغان كالېندار يوق",
    "Summarizing thread failed." : "تېمىنى خۇلاسىلەش مەغلۇب بولدى.",
    "Could not load your message thread" : "ئۇچۇر تېمىڭىزنى يۈكلىيەلمىدى",
    "The thread doesn't exist or has been deleted" : "بۇ تېما مەۋجۇت ئەمەس ياكى ئۆچۈرۈلگەن",
    "Loading thread" : "تېما يۈكلەۋاتىدۇ",
    "Not found" : "تېپىلمىدى",
    "Encrypted & verified " : "شىفىرلانغان ۋە دەلىللەنگەن ",
    "Signature verified" : "ئىمزا دەلىللەندى",
    "Signature unverified " : "ئىمزا دەلىللەنمىگەن ",
    "This message was encrypted by the sender before it was sent." : "بۇ ئۇچۇر ئەۋەتىشتىن بۇرۇن ئەۋەتكۈچى تەرىپىدىن مەخپىيلەشتۈرۈلگەن.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "بۇ ئۇچۇردا دەلىللەنگەن رەقەملىك S / MIME ئىمزاسى بار. ئۇچۇر ئەۋەتىلگەندىن بۇيان ئۆزگەرتىلمىگەن.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "بۇ ئۇچۇردا دەلىللەنمىگەن رەقەملىك S / MIME ئىمزاسى بار. ئۇچۇر ئەۋەتىلگەندىن كېيىن ئۆزگەرتىلگەن بولۇشى مۇمكىن ياكى ئىمزا قويغۇچىنىڭ گۇۋاھنامىسى ئىشەنچسىز.",
    "Reply all" : "ھەممىگە جاۋاب قايتۇرۇڭ",
    "Unsubscribe request sent" : "ئەۋەتىش ئىلتىماسى ئەۋەتىلدى",
    "Could not unsubscribe from mailing list" : "خەت ساندۇقىدىن مۇشتەرى بولالمىدى",
    "Disable reminder" : "ئەسكەرتىشنى چەكلەڭ",
    "Unsubscribe" : "مۇشتەرى بولۇش",
    "Reply to sender only" : "ئەۋەتكۈچىگە جاۋاب قايتۇرۇڭ",
    "Mark as unfavorite" : "ياقتۇرمايدىغان دەپ بەلگە قويۇڭ",
    "Mark as favorite" : "ياقتۇرىدىغان دەپ بەلگە قويۇڭ",
    "Mark as unread" : "ئوقۇلمىغان دەپ بەلگە قويۇڭ",
    "Mark as read" : "ئوقۇغاندەك بەلگە قويۇڭ",
    "Unsubscribe via link" : "ئۇلىنىش ئارقىلىق مۇشتەرى بولۇڭ",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "مۇشتەرى بولۇش خەت ئەۋەتىش تىزىملىكىدىكى بارلىق ئۇچۇرلارنى توختىتىدۇ {sender}",
    "Send unsubscribe email" : "مۇشتەرى بولمىغان ئېلېكترونلۇق خەت ئەۋەتىڭ",
    "Unsubscribe via email" : "ئېلېكترونلۇق خەت ئارقىلىق مۇشتەرى بولۇڭ",
    "{name} Assistant" : "{name} ياردەمچى",
    "Go to latest message" : "ئەڭ يېڭى ئۇچۇرغا بېرىڭ",
    "Go to newest message" : "ئەڭ يېڭى ئۇچۇرغا بېرىڭ",
    "Thread summary" : "تېما خۇلاسىسى",
    "The message could not be translated" : "بۇ ئۇچۇرنى تەرجىمە قىلىشقا بولمىدى",
    "Translation copied to clipboard" : "تەرجىمە تاختىسىغا كۆچۈرۈلگەن",
    "Translation could not be copied" : "تەرجىمىنى كۆچۈرگىلى بولمىدى",
    "Translate message" : "ئۇچۇرنى تەرجىمە قىلىڭ",
    "Source language to translate from" : "تەرجىمە قىلىدىغان مەنبە تىلى",
    "Translate from" : "دىن تەرجىمە قىلىڭ",
    "Target language to translate into" : "تەرجىمە قىلىدىغان نىشان تىل",
    "Translate to" : "تەرجىمە قىلىڭ",
    "Translating" : "تەرجىمە قىلىش",
    "Copy translated text" : "تەرجىمە قىلىنغان تېكىستنى كۆچۈرۈڭ",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "مەيداننى قۇرۇق قويۇپ ياكى 0 گە تەڭشەپ ئەخلەت ساندۇقىنى چەكلەشنى چەكلەڭ. ئەخلەت ساندۇقىنى قوزغىتىپ بولغاندىن كېيىن ئۆچۈرۈلگەن خەتلەرلا بىر تەرەپ قىلىنىدۇ.",
    "Could not remove trusted sender {sender}" : "ئىشەنچلىك ئەۋەتكۈچى {sender} ئۆچۈرەلمىدى",
    "No senders are trusted at the moment." : "ھازىر ھېچقانداق ئەۋەتكۈچىگە ئىشەنمەيدۇ.",
    "Untitled event" : "نامسىز ھادىسە",
    "(organizer)" : "(تەشكىللىگۈچى)",
    "Import into {calendar}" : "{calendar} ئىمپورت قىلىڭ",
    "Event imported into {calendar}" : "پائالىيەت {calendar} كىرگۈزۈلگەن",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "ئۇچۇش {flightNr} {depAirport} دىن {arrAirport}",
    "Airplane" : "ئايروپىلان",
    "Reservation {id}" : "زاكاس {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} {depStation} دىن {arrStation} غىچە",
    "Train from {depStation} to {arrStation}" : "{depStation} دىن {arrStation} غا بارىدىغان پويىز",
    "Train" : "پويىز",
    "Delete action" : "ھەرىكەتنى ئۆچۈرۈڭ",
    "Flag" : "بايراق",
    "The stop action ends all processing" : "توختىتىش ھەرىكىتى بارلىق بىر تەرەپ قىلىشنى ئاخىرلاشتۇرىدۇ",
    "Delete filter" : "سۈزگۈچنى ئۆچۈرۈڭ",
    "Delete mail filter {filterName}?" : "خەت سۈزگۈچنى ئۆچۈرۈڭ {filterName}?",
    "Are you sure to delete the mail filter?" : "خەت سۈزگۈچنى ئۆچۈرەمسىز؟",
    "New filter" : "يېڭى سۈزگۈچ",
    "Filter saved" : "سۈزگۈچ ساقلاندى",
    "Could not save filter" : "سۈزگۈچنى ساقلىيالمىدى",
    "Filter deleted" : "سۈزگۈچ ئۆچۈرۈلدى",
    "Could not delete filter" : "سۈزگۈچنى ئۆچۈرەلمىدى",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "ئېلېكترونلۇق خەت قالايمىقانچىلىقىڭىزنى كونترول قىلىڭ. سۈزگۈچلەر مۇھىم ئىشلارنى مۇھىم ئورۇنغا قويۇپ ، قالايمىقانچىلىقنى تۈگىتىشىڭىزگە ياردەم بېرىدۇ.",
    "Filter is active" : "سۈزگۈچ ئاكتىپ",
    "Filter is not active" : "سۈزگۈچ ئاكتىپ ئەمەس",
    "Operator" : "Operator",
    "contains" : "بار",
    "matches" : "match",
    "Delete test" : "سىناقنى ئۆچۈرۈڭ",
    "Update mail filter" : "خەت سۈزگۈچنى يېڭىلاڭ",
    "Filter name" : "سۈزگۈچ ئىسمى",
    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "ئىمتىھان ئېلېكترونلۇق خەت مۇلازىمېتىرىڭىزدىكى كەلگەن ئېلېكترونلۇق خەتلەرگە ، تېما (ئېلېكترونلۇق خەتنىڭ تېما لىنىيىسى) ، (ئەۋەتكۈچى) ۋە (تاپشۇرۇۋالغۇچى) غا ئوخشاش ساھەگە ئىشلىتىلىدۇ. تۆۋەندىكى مەشغۇلاتلارنى ئىشلىتىپ بۇ ساھەنىڭ شەرتلىرىنى بەلگىلىيەلەيسىز:",
    "An exact match. The field must be identical to the provided value." : "ئېنىق ماس. بۇ ساھە چوقۇم تەمىنلەنگەن قىممەت بىلەن ئوخشاش بولۇشى كېرەك.",
    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Subring match. ئەگەر تەمىنلەنگەن قىممەت ئۇنىڭ ئىچىدە بولسا ، مەيدان ماس كېلىدۇ. مەسىلەن ، «دوكلات» «پورت» بىلەن ماس كېلىدۇ.",
    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ياۋايى كارتا ئىشلىتىپ ئەندىزە ماس كېلىدۇ. \"*\" بەلگىسى ھەرپ-بەلگىلەرنى كۆرسىتىدۇ (ھېچقايسىسىنى ئۆز ئىچىگە ئالمايدۇ) ، \"?\" دەل بىر ھەرپكە ۋەكىللىك قىلىدۇ. مەسىلەن ، «* دوكلات *» «سودا دوكلاتى 2024» بىلەن ماس كېلىدۇ.",
    "Actions are triggered when the specified tests are true. The following actions are available:" : "كۆرسىتىلگەن سىناقلار توغرا بولغاندا ھەرىكەت قوزغىلىدۇ. تۆۋەندىكى ھەرىكەتلەر بار:",
    "Moves the message into a specified folder." : "ئۇچۇرنى بەلگىلەنگەن قىسقۇچقا يۆتكەيدۇ.",
    "Adds a flag to the message." : "ئۇچۇرغا بايراق قوشىدۇ.",
    "Halts the execution of the filter script. No further filters with will be processed after this action." : "سۈزگۈچ قوليازمىسىنىڭ ئىجرا قىلىنىشىنى توختىتىدۇ. بۇ ھەرىكەتتىن كېيىن باشقا سۈزگۈچلەر بىر تەرەپ قىلىنمايدۇ.",
    "Priority" : "ھەممىدىن مۇھىم",
    "Enable filter" : "سۈزگۈچنى قوزغىتىڭ",
    "Save filter" : "سۈزگۈچنى ساقلاڭ",
    "Successfully updated config for \"{domain}\"" : "\"{domain}\" ئۈچۈن مۇۋەپپەقىيەتلىك يېڭىلاندى.",
    "Error saving config" : "سەپلىمە خاتا",
    "Saved config for \"{domain}\"" : "\"{domain}\" ئۈچۈن ساقلانغان سەپلىمە",
    "Could not save provisioning setting" : "تەمىنلەش تەڭشىكىنى ساقلىيالمىدى",
    "There was an error when provisioning accounts." : "ھېسابات تەمىنلىگەندە خاتالىق كۆرۈلدى.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\" نىڭ ھېساباتلىرى مۇۋەپپەقىيەتلىك ئۆچۈرۈلدى ۋە ئەمەلدىن قالدۇرۇلدى.",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "\"{domain}\" ھېساباتلىرىنى ئۆچۈرۈش ۋە رەتلەشتە خاتالىق",
    "Could not save default classification setting" : "سۈكۈتتىكى تۈرگە ئايرىشنى ساقلىيالمىدى",
    "Mail app" : "خەت ئەپى",
    "The mail app allows users to read mails on their IMAP accounts." : "خەت ئەپى ئابونتلارنىڭ IMAP ھېساباتىدىكى خەتلەرنى ئوقۇيالايدۇ.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "بۇ يەردىن مىسال تەڭشەكلىرىنى تاپالايسىز. ئىشلەتكۈچىنىڭ ئالاھىدە تەڭشىكى ئەپنىڭ ئۆزىدە (سول تەرەپ سول تەرەپ).",
    "Account provisioning" : "ھېسابات بىلەن تەمىنلەش",
    "A provisioning configuration will provision all accounts with a matching email address." : "تەمىنات سەپلىمىسى بارلىق ھېساباتلارنى ماس كېلىدىغان ئېلېكترونلۇق خەت ئادرېسى بىلەن تەمىنلەيدۇ.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "تەمىنلىگۈچى دائىرە رايونىدا ياۋا كارتا (*) نى ئىشلىتىپ ، باشقا سەپلىمىگە ماس كەلمىسە ، بارلىق ئىشلەتكۈچىلەرگە ماس كېلىدىغان سەپلىمە ھاسىل قىلىدۇ.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "تەمىنلەش مېخانىزمى ياۋايى كارتا دائىرە سەپلىمىسىدىن ئالاھىدە دائىرە سەپلىمىسىنى ئالدىنقى ئورۇنغا قويىدۇ.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "ئىشلەتكۈچى ئاللىقاچان باشقا سەپلىمە بىلەن تەمىنلەنگەندىن كېيىن يېڭى ماس كېلىدىغان سەپلىمە تېپىلسا ، يېڭى سەپلىمە ئالدىنقى ئورۇنغا قويۇلۇپ ، ئىشلەتكۈچى سەپلىمىسى بىلەن قايتا تۈزىتىلىدۇ.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "ھەر بىر دائىرە ئىچىدە پەقەت بىرلا سەپلىمە بولىدۇ ، پەقەت بىرلا ياۋا كارتا دائىرە سەپلىمىسى بولىدۇ.",
    "These settings can be used in conjunction with each other." : "بۇ تەڭشەكلەرنى ئۆز-ئارا بىرلەشتۈرۈپ ئىشلىتىشكە بولىدۇ.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "ئەگەر بارلىق ئىشلەتكۈچىلەر ئۈچۈن پەقەت بىرلا تور نامىنى تەمىنلىمەكچى بولسىڭىز ، ياۋايى كارتا (*) نى ئىشلىتىڭ.",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "ئەگەر بۇ تەشكىلاتنىڭ Nextcloud ۋە ئېلخەت مۇلازىمېتىرىڭىزغا ئوخشاش ئىشلەتكۈچىنىڭ ئارقا تەرىپىنى ئىشلەتسىڭىز ، بۇ تەڭشەك ئەڭ ئەقىلگە مۇۋاپىق.",
    "Provisioning Configurations" : "سەپلىمىنى تەمىنلەش",
    "Add new config" : "يېڭى سەپلىمە قوشۇڭ",
    "Provision all accounts" : "بارلىق ھېساباتلارنى تەمىنلەڭ",
    "Allow additional mail accounts" : "قوشۇمچە خەت ھېساباتىغا يول قويۇڭ",
    "Allow additional Mail accounts from User Settings" : "ئىشلەتكۈچى تەڭشەكلىرىدىن قوشۇمچە خەت ھېساباتىغا يول قويۇڭ",
    "Enable text processing through LLMs" : "LLM ئارقىلىق تېكىست بىر تەرەپ قىلىشنى قوزغىتىڭ",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "خەت ئەپى سەپلەنگەن چوڭ تىل ئەندىزىسىنىڭ ياردىمىدە ئىشلەتكۈچى سانلىق مەلۇماتلىرىنى بىر تەرەپ قىلالايدۇ ۋە تېما خۇلاسىسى ، ئەقلىي جاۋاب ۋە پائالىيەت كۈن تەرتىپى قاتارلىق ياردەم ئىقتىدارلىرى بىلەن تەمىنلەيدۇ.",
    "Enable LLM processing" : "LLM بىر تەرەپ قىلىشنى قوزغىتىڭ",
    "Enable classification by importance by default" : "كۆڭۈلدىكى قىممىتى بويىچە تۈرگە ئايرىشنى قوزغىتىڭ",
    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "خەت ئەپى كەلگەن ئېلېكترونلۇق خەتلەرنى ماشىنا ئۆگىنىشى ئارقىلىق مۇھىم ئورۇنغا ئايرىيالايدۇ. بۇ ئىقتىدار سۈكۈتتىكى ھالەتتە قوزغىتىلغان ، ئەمما بۇ يەردە سۈكۈتتىكى ھالەتتە چەكلىگىلى بولىدۇ. يەككە ئىشلەتكۈچىلەر يەنىلا ھېساباتىدىكى ئىقتىدارنى ئالماشتۇرالايدۇ.",
    "Enable classification of important mails by default" : "سۈكۈتتىكى مۇھىم خەتلەرنى تۈرگە ئايرىشنى قوزغىتىڭ",
    "Anti Spam Service" : "ئەخلەت خەتكە قارشى تۇرۇش مۇلازىمىتى",
    "You can set up an anti spam service email address here." : "سىز بۇ يەردىن ئەخلەت خەتكە قارشى مۇلازىمەت ئېلېكترونلۇق خەت ئادرېسىنى قۇرالايسىز.",
    "Any email that is marked as spam will be sent to the anti spam service." : "ئەخلەت خەت دەپ بەلگە قويۇلغان ھەر قانداق ئېلېكترونلۇق خەت ئەخلەت خەتكە قارشى تۇرۇش مۇلازىمىتىگە ئەۋەتىلىدۇ.",
    "Gmail integration" : "Gmail بىرلەشتۈرۈش",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail ئابونتلارنىڭ ئېلېكترونلۇق خەتلىرىنى IMAP ئارقىلىق زىيارەت قىلالايدۇ. بىخەتەرلىك سەۋەبىدىن بۇ زىيارەت پەقەت OAuth 2.0 ئۇلىنىشى ياكى ئىككى ئامىللىق دەلىللەش ۋە ئەپ مەخپىي نومۇرىنى ئىشلىتىدىغان Google ھېساباتى بىلەنلا مۇمكىن.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Google Cloud كونترول سۇپىسىدا «تور قوللىنىشچان پروگراممىسى» ئۈچۈن يېڭى خېرىدار كىملىكىنى تىزىملىتىشىڭىز كېرەك. ھوقۇق بېرىلگەن قايتا نىشانلانغان URI سۈپىتىدە URL {url} نى قوشۇڭ.",
    "Microsoft integration" : "مىكروسوفتنىڭ بىر گەۋدىلىشىشى",
    "Successfully set up anti spam email addresses" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەت ئادرېسىنى مۇۋەپپەقىيەتلىك ئورنىتىڭ",
    "Error saving anti spam email addresses" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەت ئادرېسىنى ساقلاشتا خاتالىق",
    "Successfully deleted anti spam reporting email" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەتنى مۇۋەپپەقىيەتلىك ئۆچۈردى",
    "Error deleting anti spam reporting email" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەتنى ئۆچۈرۈشتە خاتالىق",
    "Anti Spam" : "ئەخلەت خەتكە قارشى تۇرۇش",
    "Add the email address of your anti spam report service here." : "ئەخلەت خەتكە قارشى تۇرۇش مۇلازىمىتىڭىزنىڭ ئېلېكترونلۇق خەت ئادرېسىنى بۇ يەرگە قوشۇڭ.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "بۇ تەڭشەكنى ئىشلەتكەندە ، ئىشلەتكۈچى «ئەخلەت خەت دەپ بەلگە» نى چەككەندە ، ئېلېكترونلۇق خەت SPAM دوكلات مۇلازىمېتىرىغا ئەۋەتىلىدۇ.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "ئەسلى ئۇچۇر «ئۇچۇر / rfc822» قوشۇمچە قىلىپ باغلىنىدۇ.",
    "\"Mark as Spam\" Email Address" : "«ئەخلەت خەت دەپ بەلگە» ئېلېكترونلۇق خەت ئادرېسى",
    "\"Mark Not Junk\" Email Address" : "«ئەخلەت ئەمەس بەلگە» ئېلېكترونلۇق خەت ئادرېسى",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "Google integration configured" : "Google بىرلەشتۈرۈلدى",
    "Could not configure Google integration" : "Google بىرلەشتۈرۈشنى تەڭشىيەلمىدى",
    "Google integration unlinked" : "گۇگۇلنىڭ بىر گەۋدىلەشتۈرۈلمىگەن",
    "Could not unlink Google integration" : "گۇگۇلنىڭ بىر گەۋدىلىشىشىنى ئاچالمىدى",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "Unlink" : "Unlink",
    "Microsoft integration configured" : "Microsoft بىر گەۋدىلەشتۈرۈلگەن",
    "Could not configure Microsoft integration" : "Microsoft بىرلەشتۈرۈشنى تەڭشىيەلمىدى",
    "Microsoft integration unlinked" : "مىكروسوفتنىڭ بىر گەۋدىلەشتۈرۈلمىگەن",
    "Could not unlink Microsoft integration" : "مىكروسوفتنىڭ بىر گەۋدىلىشىشىنى ئاچالمىدى",
    "Tenant ID (optional)" : "ئىجارە ئالغۇچىنىڭ كىملىكى (ئىختىيارىي)",
    "Domain Match: {provisioningDomain}" : "دائىرە مۇسابىقىسى: {provisioningDomain}",
    "Email: {email}" : "ئېلخەت: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} {host}: {port} ({ssl} مەخپىيلەشتۈرۈش)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} دىكى {host}: {port} ({ssl} مەخپىيلەشتۈرۈش)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "ئەلگەك: {user} دىكى {host}: {port} ({ssl} مەخپىيلەشتۈرۈش)",
    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\" نىڭ سەپلىمىسى",
    "Provisioning domain" : "دائىرە بىلەن تەمىنلەش",
    "Email address template" : "ئېلېكترونلۇق خەت ئادرېسى قېلىپى",
    "IMAP" : "IMAP",
    "User" : "ئىشلەتكۈچى",
    "Host" : "باش ئاپپارات",
    "Port" : "ئېغىز",
    "SMTP" : "SMTP",
    "Master password" : "ئاساسىي پارول",
    "Use master password" : "ئاساسىي پارول ئىشلىتىڭ",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "ئەلگەك بىرلەشتۈرۈشنى قوزغىتىڭ",
    "LDAP aliases integration" : "LDAP بىرلەشتۈرۈشنى ئۆزگەرتىدۇ",
    "Enable LDAP aliases integration" : "LDAP تاشقى پىلانېت بىرلەشتۈرۈشنى قوزغىتىڭ",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP ئۆزگەرتىلگەن بىرىكمە سەپلىمە LDAP مۇندەرىجىسىدىن ئېلېكترونلۇق خەت ئادرېسى بىلەن تەمىنلەيدىغان خاسلىقنى ئوقۇيدۇ.",
    "LDAP attribute for aliases" : "LDAP خاسلىقى",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "ئېلېكترونلۇق خەت ئادرېسى بىلەن تەمىنلەيدىغان كۆپ خىل قىممەت خاسلىقى. ھەر بىر قىممەت ئۈچۈن بىر تەخەللۇس قۇرۇلدى. Nextcloud دا بار بولغان LDAP مۇندەرىجىسىدە يوق.",
    "Save Config" : "Save Config",
    "Unprovision & Delete Config" : "Unprovision & Delete Config",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "*% USERID% ۋە% EMAIL% ئىشلەتكۈچىنىڭ UID ۋە ئېلېكترونلۇق خەت ساندۇقىنىڭ ئورنىنى ئالىدۇ",
    "With the settings above, the app will create account settings in the following way:" : "يۇقىرىدىكى تەڭشەكلەر بىلەن بۇ دېتال تۆۋەندىكى ئۇسۇلدا ھېسابات تەڭشىكى قۇرىدۇ:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "تەمىنلەنگەن PKCS # 12 گۇۋاھنامىسىدە كەم دېگەندە بىر گۇۋاھنامە ۋە ئېنىق بىر شەخسىي ئاچقۇچ بولۇشى كېرەك.",
    "Failed to import the certificate. Please check the password." : "گۇۋاھنامىنى ئەكىرىش مەغلۇب بولدى. پارولنى تەكشۈرۈپ بېقىڭ.",
    "Certificate imported successfully" : "مۇۋەپپەقىيەتلىك ئىمپورت قىلىنغان گۇۋاھنامە",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "گۇۋاھنامىنى ئەكىرىش مەغلۇب بولدى. شەخسىي ئاچقۇچنىڭ گۇۋاھنامىگە ماس كېلىدىغانلىقى ۋە ئىم بىلەن قوغدالمىغانلىقىغا كاپالەتلىك قىلىڭ.",
    "Failed to import the certificate" : "گۇۋاھنامىنى ئەكىرىش مەغلۇب بولدى",
    "S/MIME certificates" : "S / MIME گۇۋاھنامىسى",
    "Certificate name" : "گۇۋاھنامە ئىسمى",
    "E-mail address" : "ئېلېكترونلۇق خەت ئادرېسى",
    "Valid until" : "كۈچكە ئىگە",
    "Delete certificate" : "گۇۋاھنامىنى ئۆچۈرۈڭ",
    "No certificate imported yet" : "تېخى ئىمپورت قىلىنغان گۇۋاھنامە يوق",
    "Import certificate" : "گۇۋاھنامە ئەكىرىش",
    "Import S/MIME certificate" : "S / MIME گۇۋاھنامىسىنى ئەكىرىڭ",
    "PKCS #12 Certificate" : "PKCS # 12 گۇۋاھنامىسى",
    "PEM Certificate" : "PEM گۇۋاھنامىسى",
    "Certificate" : "گۇۋاھنامە",
    "Private key (optional)" : "شەخسىي ئاچقۇچ (ئىختىيارى)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "ئەگەر بۇ گۇۋاھنامە ئارقىلىق ئىمزا قويۇلغان ۋە مەخپىيلەشتۈرۈلگەن ئېلېكترونلۇق خەت ئەۋەتمەكچى بولسىڭىز ، شەخسىي ئاچقۇچ تەلەپ قىلىنىدۇ.",
    "Submit" : "يوللاڭ",
    "Account connected" : "ھېسابات ئۇلاندى",
    "You can close this window" : "بۇ كۆزنەكنى ياپالايسىز",
    "Connect your mail account" : "خەت ساندۇقىڭىزنى ئۇلاڭ",
    "To add a mail account, please contact your administrator." : "خەت ھېساباتى قوشۇش ئۈچۈن باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "All" : "ھەممىسى",
    "Drafts" : "Drafts",
    "Favorites" : "يىغقۇچ",
    "Priority inbox" : "مۇھىم خەت ساندۇقى",
    "All inboxes" : "بارلىق خەت ساندۇقى",
    "Inbox" : "خەت ساندۇقى",
    "Junk" : "Junk",
    "Sent" : "ئەۋەتىلدى",
    "Trash" : "ئەخلەت ساندۇقى",
    "Connect OAUTH2 account" : "OAUTH2 ھېساباتىنى ئۇلاڭ",
    "Error while sharing file" : "ھۆججەتنى ھەمبەھىرلەشتە خاتالىق",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "ئىلگىرى بىر ئۇچۇر بار. داۋاملاشتۇرسىڭىز بارلىق ساقلانمىغان ئۆزگىرىشلەر يوقىلىدۇ!",
    "Discard changes" : "ئۆزگەرتىشلەرنى ئەمەلدىن قالدۇرۇڭ",
    "Discard unsaved changes" : "ساقلانمىغان ئۆزگەرتىشلەرنى تاشلاڭ",
    "Keep editing message" : "ئۇچۇرنى تەھرىرلەشنى داۋاملاشتۇرۇڭ",
    "Attachments were not copied. Please add them manually." : "قوشۇمچە ھۆججەتلەر كۆچۈرۈلمىدى. ئۇلارنى قولدا قوشۇڭ.",
    "Could not create snooze mailbox" : "ئۇخلاش خەت ساندۇقى قۇرالمىدى",
    "Message sent" : "ئۇچۇر ئەۋەتىلدى",
    "Could not send message" : "ئۇچۇر ئەۋەتەلمىدى",
    "Could not load {tag}{name}{endtag}" : "يۈكلىيەلمىدى {tag} {name} {endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "{tag} {name} {endtag} نى يۈكلەشتە مەسىلە كۆرۈلدى",
    "Could not load your message" : "ئۇچۇرىڭىزنى يۈكلىيەلمىدى",
    "Could not load the desired message" : "لازىملىق ئۇچۇرنى يۈكلىيەلمىدى",
    "Could not load the message" : "ئۇچۇرنى يۈكلىيەلمىدى",
    "Error loading message" : "ئۇچۇر يۈكلەشتە خاتالىق",
    "Forwarding to %s" : "% S غا يوللاش",
    "Click here if you are not automatically redirected within the next few seconds." : "كەلگۈسى بىر نەچچە سېكۇنت ئىچىدە ئاپتوماتىك قايتا نىشانلانمىسىڭىز بۇ يەرنى چېكىڭ.",
    "Redirect" : "قايتا نىشانلاش",
    "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
    "Continue to %s" : "داۋاملىق% s",
    "Mailbox search" : "خەت ساندۇقى ئىزدەش",
    "Install Mailvelope browser extension by clicking here" : "بۇ يەرنى چېكىپ Mailvelope توركۆرگۈ كېڭەيتىلمىسىنى قاچىلاڭ",
    "No messages in this mailbox" : "بۇ خەت ساندۇقىدا ھېچقانداق ئۇچۇر يوق",
    "No trash mailbox configured" : "ئەخلەت خەت ساندۇقى سەپلەنمىگەن",
    "Draft: " : "لايىھە: ",
    "To archive a message please configure an archive mailbox in account settings" : "ئۇچۇرنى ئارخىپلاشتۇرۇش ئۈچۈن ھېسابات تەڭشىكىدە ئارخىپ خەت ساندۇقىنى سەپلەڭ",
    "Could not open mailbox" : "خەت ساندۇقىنى ئاچالمىدى",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ئۇچۇرلىرىڭىزنى كۆرسەتمەكتە. چوڭراق خەت ساندۇقىغا بىر ئاز ئۇزۇن ۋاقىت كېتىدۇ.",
    "Choose target mailbox" : "نىشان خەت ساندۇقىنى تاللاڭ",
    "Show only subscribed mailboxes" : "پەقەت مۇشتەرى بولغان خەت ساندۇقىنىلا كۆرسىتىڭ",
    "Add mailbox" : "خەت ساندۇقى قوشۇڭ",
    "Mailbox name" : "خەت ساندۇقىنىڭ ئىسمى",
    "Show all subscribed mailboxes" : "بارلىق مۇشتەرى بولغان خەت ساندۇقىنى كۆرسەت",
    "Show all mailboxes" : "بارلىق خەت ساندۇقىنى كۆرسەت",
    "Clear mailbox" : "خەت ساندۇقىنى تازىلاش",
    "The mailbox and all messages in it will be deleted." : "خەت ساندۇقى ۋە ئۇنىڭدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
    "Delete mailbox" : "خەت ساندۇقىنى ئۆچۈرۈڭ",
    "Delete mailbox {name}" : "خەت ساندۇقىنى ئۆچۈرۈڭ {name}",
    "Mark all messages of this mailbox as read" : "بۇ خەت ساندۇقىنىڭ بارلىق ئۇچۇرلىرىنى ئوقۇغاندەك بەلگە قويۇڭ",
    "Add submailbox" : "تارماق خەت ساندۇقى قوشۇڭ",
    "Move mailbox" : "خەت ساندۇقىنى يۆتكەڭ",
    "Repair mailbox" : "خەت ساندۇقىنى رېمونت قىلىڭ",
    "No sent mailbox configured. Please pick one in the account settings." : "ئەۋەتىلگەن خەت ساندۇقى سەپلەنمىگەن. ھېسابات تەڭشىكىدىن بىرنى تاللاڭ.",
    "Could not copy to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرەلمىدى",
    "Copy to \"Sent\" Mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈڭ",
    "Copy to Sent Mailbox" : "ئەۋەتىلگەن خەت ساندۇقىغا كۆچۈرۈڭ",
    "Search in mailbox" : "خەت ساندۇقىدىن ئىزدەڭ",
    "If all tests pass, then the actions will be executed" : "ئەگەر بارلىق سىناقلار ئۆتۈپ كەتسە ، ھەرىكەتلەر ئىجرا بولىدۇ",
    "If one test pass, then the actions will be executed" : "ئەگەر بىر سىناقتىن ئۆتسە ، ئۇنداقتا ھەرىكەت ئىجرا بولىدۇ",
    "Tests" : "سىناق",
    "New test" : "يېڭى سىناق",
    "Actions" : "مەشغۇلاتلار",
    "New action" : "يېڭى ھەرىكەت",
    "Message copied to \"Sent\" mailbox" : "ئۇچۇر «ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈلدى",
    "Could not copy message to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا ئۇچۇر كۆچۈرەلمىدى"
},
"nplurals=2; plural=(n != 1);");
